@@ -1,4 +1,5 @@
 import asyncio
+import sys
 import threading
 from asyncio import QueueEmpty as AsyncQueueEmpty
 from asyncio import QueueFull as AsyncQueueFull
@@ -6,24 +7,85 @@ from collections import deque
 from heapq import heappop, heappush
 from queue import Empty as SyncQueueEmpty
 from queue import Full as SyncQueueFull
-from typing import Any, Callable, Deque, Generic, List, Optional, Set, TypeVar
+from typing import Any, Callable, Generic, Optional, Protocol, TypeVar
 
-__version__ = "0.6.1"
-__all__ = ("Queue", "PriorityQueue", "LifoQueue")
+__version__ = "1.1.0"
+__all__ = (
+    "Queue",
+    "PriorityQueue",
+    "LifoQueue",
+    "SyncQueue",
+    "SyncQueueEmpty",
+    "SyncQueueFull",
+    "AsyncQueue",
+    "AsyncQueueEmpty",
+    "AsyncQueueFull",
+    "BaseQueue",
+)
 
 
 T = TypeVar("T")
 OptFloat = Optional[float]
 
 
-current_loop = getattr(asyncio, "get_running_loop", None)
-if current_loop is None:
-    current_loop = asyncio.get_event_loop
+class BaseQueue(Protocol[T]):
+    @property
+    def maxsize(self) -> int:
+        ...
+
+    @property
+    def closed(self) -> bool:
+        ...
+
+    def task_done(self) -> None:
+        ...
+
+    def qsize(self) -> int:
+        ...
+
+    @property
+    def unfinished_tasks(self) -> int:
+        ...
+
+    def empty(self) -> bool:
+        ...
+
+    def full(self) -> bool:
+        ...
+
+    def put_nowait(self, item: T) -> None:
+        ...
+
+    def get_nowait(self) -> T:
+        ...
+
+
+class SyncQueue(BaseQueue[T], Protocol[T]):
+
+    def put(self, item: T, block: bool = True, timeout: OptFloat = None) -> None:
+        ...
+
+    def get(self, block: bool = True, timeout: OptFloat = None) -> T:
+        ...
+
+    def join(self) -> None:
+        ...
+
+
+class AsyncQueue(BaseQueue[T], Protocol[T]):
+    async def put(self, item: T) -> None:
+        ...
+
+    async def get(self) -> T:
+        ...
+
+    async def join(self) -> None:
+        ...
 
 
 class Queue(Generic[T]):
     def __init__(self, maxsize: int = 0) -> None:
-        self._loop = current_loop()
+        self._loop = asyncio.get_running_loop()
         self._maxsize = maxsize
 
         self._init(maxsize)
@@ -36,13 +98,16 @@ class Queue(Generic[T]):
         self._all_tasks_done = threading.Condition(self._sync_mutex)
 
         self._async_mutex = asyncio.Lock()
+        if sys.version_info[:3] == (3, 10, 0):
+            # Workaround for Python 3.10 bug, see #358:
+            getattr(self._async_mutex, "_get_loop", lambda: None)()
         self._async_not_empty = asyncio.Condition(self._async_mutex)
         self._async_not_full = asyncio.Condition(self._async_mutex)
         self._finished = asyncio.Event()
         self._finished.set()
 
         self._closing = False
-        self._pending = set()  # type: Set[asyncio.Future[Any]]
+        self._pending: set[asyncio.Future[Any]] = set()
 
         def checked_call_soon_threadsafe(
             callback: Callable[..., None], *args: Any
@@ -108,7 +173,7 @@ class Queue(Generic[T]):
     # These will only be called with appropriate locks held
 
     def _init(self, maxsize: int) -> None:
-        self._queue = deque()  # type: Deque[T]
+        self._queue: deque[T] = deque()
 
     def _qsize(self) -> int:
         return len(self._queue)
@@ -138,7 +203,7 @@ class Queue(Generic[T]):
             with self._sync_mutex:
                 self._sync_not_full.notify()
 
-        fut = self._loop.run_in_executor(None, f)
+        fut = asyncio.ensure_future(self._loop.run_in_executor(None, f))
         fut.add_done_callback(self._pending.discard)
         self._pending.add(fut)
 
@@ -177,7 +242,7 @@ class Queue(Generic[T]):
             raise RuntimeError("Operation on the closed queue is forbidden")
 
 
-class _SyncQueueProxy(Generic[T]):
+class _SyncQueueProxy(SyncQueue[T]):
     """Create a queue object with a given maximum size.
 
     If maxsize is <= 0, the queue size is infinite.
@@ -350,7 +415,7 @@ class _SyncQueueProxy(Generic[T]):
         return self.get(block=False)
 
 
-class _AsyncQueueProxy(Generic[T]):
+class _AsyncQueueProxy(AsyncQueue[T]):
     """Create a queue object with a given maximum size.
 
     If maxsize is <= 0, the queue size is infinite.
@@ -532,7 +597,7 @@ class PriorityQueue(Queue[T]):
     """
 
     def _init(self, maxsize: int) -> None:
-        self._heap_queue = []  # type: List[T]
+        self._heap_queue: list[T] = []
 
     def _qsize(self) -> int:
         return len(self._heap_queue)
